<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Pemantau Sistem</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Pemantau Sistem ialah sebuah alat yang memantau beban sistem masa nyata, lihat dan kawal proses-proses dan perkhidmatan-perkhidmatan dalam sistem anda.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Sembunyi perincian</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Baca</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Tulis</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saat</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 hari %2 jam %3 minit</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Penggunaan</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frekuensi semasa</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekuensi</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Pembekal</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Soket</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Pemproses logikal</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Pemayaan</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Cache L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Cache L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Cache L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Cache L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Purata beban</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Huraian fail</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Jaluran</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nama hos</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Jenis OS</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Masa hidup</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saat</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktif</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>memuat semula</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>tidak aktif</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>gagal</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>diaktifkan</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>dinyahaktifkan</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>tidak-ditemui</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>tetapan-bermasalah</translation>
    </message>
    <message>
        <source>error</source>
        <translation>ralat</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>digabungkan</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>ditopengkan</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>dimuatkan</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>T/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>dibenarkan</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>dilumpuhkan</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statik</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>sementara</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>tidak langsung</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>masa-jalan-dibenarkan</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>ditopengkan</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>dijana</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>mati</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>pra-mula</translation>
    </message>
    <message>
        <source>start</source>
        <translation>mula</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>pasca-mula</translation>
    </message>
    <message>
        <source>running</source>
        <translation>berjalan</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>keluar</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>muat semula</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>henti</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>henti-pemantau</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>henti-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>henti-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>henti-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>akhir-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>akhir-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>gagal</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-mula-semula</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Digunakan</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tersedia</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Dikongsi</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Dicache</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Penimbal</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Silih dicache</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Tidak aktif</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Kotor</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Dipeta</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Jumlah silih</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Silih bebas</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Kelajuan baca</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Kelajuan tulis</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapasiti</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Baca sektor</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Baca/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Baca sektor/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Gabung baca/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sektor ditulis</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Tulis lengkap</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Tulis gabung</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Tulis/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sektor ditulis/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Gabung tulis/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Penamatan proses ini boleh mengakibatkan kehilangan data.
Anda pasti mahu teruskannya?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Tamatkan proses</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Paksa penamatan proses ini boleh mengakibatkan kehilangan data.
Anda pasti mahu teruskannya?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Paksa penamatan aplikasi ini boleh mengakibatkan kehilangan data.
Anda pasti mahu teruskannya?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Paksa Penamatan</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Tamatkan</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Alamat IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Topeng Internet:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Siaran:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Skop:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Jenis sambungan</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Kualiti pautan</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Kekuatan isyarat</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Aras hingar</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Jalur lebar</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paket RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bait RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Ralat 
RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX jatuh</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Lampau RX</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Bingkai RX</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paket TX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bait TX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Ralat TX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Lampau TX</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Pembawa TX</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX jatuh</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Baris perintah</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Masa mula</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik aplikasi yang anda mahu tamatkan</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Ingatan</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Terima</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Baca cakera</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Tulis cakera</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Ingatan</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Silih</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Tidak dibenarkan</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Muat turun</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Muat naik</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rangkaian</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Jumlah Terima</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Jumlah Hantar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Hantar</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Cakera</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Sangat tinggi</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Sangat rendah</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Suai</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Tidak sah</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Ralat: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Gagal mengubah prioriti proses</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplikasi</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Proses Saya</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Semua proses</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Gagal menjeda proses</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Gagal menyambung semula proses</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Gagal membunuh proses</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ralat tidak diketahui</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Gagal menghantar isyarat ke proses</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Gagal menamatkan proses</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplikasi dan %2 proses masih berjalan)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Tiada respons</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguh</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Talam</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Lihat lokasi perintah</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Sifat</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Tamatkan proses</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Sambung semula proses</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Bunuh proses</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Ubah prioriiti</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Tangguh proses</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Suai Prioriti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Ubah</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Ingatan</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Tulis cakera</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Baca cakera</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Muat turun</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Muat naik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Elok</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioriti</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Ingatan terkongsi</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Ingatan maya</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Tiada sokongan</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Gagal menetapkan jenis permulaan perkhidmatan</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Ralat: Gagal menetapkan jenis permulaan perkhidmatan yang disebabkan oleh kerosakan proses sub.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nama tika perkhidmatan</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Segar semula</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mula</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Henti</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Mula semula</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Jenis permulaan</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Beban</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Keadaan</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Keterangan</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Jenis Permulaan</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Paksa penamatan aplikasi</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Kembang</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Padat</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Perkhidmatan</translation>
    </message>
</context>
</TS>
